elephant.spike\_train\_generation.StationaryInverseGaussianProcess
==================================================================

.. currentmodule:: elephant.spike_train_generation

.. autoclass:: StationaryInverseGaussianProcess
   :members:
   :inherited-members:
   :special-members: __call__, __getitem__, __setitem__

   

   
   .. rubric:: Methods

   .. autosummary::
   
      ~StationaryInverseGaussianProcess.__init__
      ~StationaryInverseGaussianProcess.generate_n_spiketrains
      ~StationaryInverseGaussianProcess.generate_spiketrain
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~StationaryInverseGaussianProcess.expected_cv
      ~StationaryInverseGaussianProcess.t_start
      ~StationaryInverseGaussianProcess.t_stop
      ~StationaryInverseGaussianProcess.isi_generator
   
   